@@ -13,7 +13,7 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use base qw/Exporter/;
 
-our $VERSION   = 0.96005;
+our $VERSION   = 0.96006;
 our @EXPORT_OK = qw/get_options/;
 our %p2u_extra;
 
@@ -22,7 +22,7 @@ sub get_options {
     my ($caller_package) = caller;
     $caller_package .= '.pm';
     $caller_package =~ s{::}{/}g;
-    $caller_package = $INC{$caller_package};
+    $caller_package = $INC{$caller_package} || $0;
 
     Getopt::Long::Configure('bundling');
     GetOptions(
@@ -39,7 +39,7 @@ sub get_options {
     ) and return;
 
     if ( $option->{'version'} ) {
-        my $name = "${caller_package}::name";
+        my $name = (caller)[0] . '::name';
         no strict qw/refs/; ## no critic
         print "${$name} Version = $VERSION\n";
         return;
@@ -75,7 +75,7 @@ sub pod2usage {
                 $found = 1;
             }
             elsif ($found) {
-                print {*STDERR} $_;
+                print $_;
             }
         }
     }
@@ -96,7 +96,7 @@ App::Git::Workflow::Command - Helper for other commands
 
 =head1 VERSION
 
-This documentation refers to App::Git::Workflow::Command version 0.96005
+This documentation refers to App::Git::Workflow::Command version 0.96006
 
 =head1 SYNOPSIS
 
